==> anyconnect-linux64-4.10.06090-predeploy-k9.tar.gz: anyconnect-linux64-4.10.06090/iseposture/bin/iseposture_uninstall.sh <==
#!/bin/sh
#

BASH_BASE_SIZE=0x00000b32
CISCO_AC_TIMESTAMP=0x0000000063c72014
CISCO_AC_OBJNAME=iseposture_uninstall.sh                                         
# BASH_BASE_SIZE=0x00000000 is required for signing
# the comment is after or else the code signing tool will find the comment

ANYCONNECT_INSTPREFIX="/opt/cisco/anyconnect"
ANYCONNECT_BINDIR="${ANYCONNECT_INSTPREFIX}/bin"
ANYCONNECT_LIBDIR="${ANYCONNECT_INSTPREFIX}/lib"
ANYCONNECT_PLUGINDIR="${ANYCONNECT_BINDIR}/plugins"
ISEPOSTURE_PROFILEDIR="${ANYCONNECT_INSTPREFIX}/iseposture"
ISEPOSTURE_SCRIPTDIR="${ISEPOSTURE_PROFILEDIR}/scripts"


LOGDIR="/var/log/anyconnect"
LOG="${LOGDIR}/iseposture-uninstall.log"

ISEBINFILES="aciseposture aciseagentd iseposture_uninstall.sh manifesttool_iseposture"
ISELIBFILES="libacise.so"
ISEPLUGINFILES="libacisectrl.so libaciseshim.so"

# Create log directory if not exist
if [ ! -d ${LOGDIR} ]; then
  mkdir -p ${LOGDIR} >/dev/null 2>&1
fi

echo "Uninstalling Cisco AnyConnect ISE Posture Module..."
echo "Uninstalling Cisco AnyConnect ISE Posture Module..." > "${LOG}"
echo `whoami` "invoked $0 from " `pwd` " at " `date` >> "${LOG}"

# Check for root privileges
if [ `id | sed -e 's/(.*//'` != "uid=0" ]; then
  echo "Sorry, you need super user privileges to run this script."
  echo "Sorry, you need super user privileges to run this script." >> "${LOG}"
  exit 1
fi

# update the VPNManifest.dat
ISEPOSTUREMANIFEST="ACManifestISEPosture.xml"
echo "${ANYCONNECT_BINDIR}/manifesttool_iseposture -x ${ANYCONNECT_INSTPREFIX} ${ANYCONNECT_INSTPREFIX}/${ISEPOSTUREMANIFEST}" >> "${LOG}"
${ANYCONNECT_BINDIR}/manifesttool_iseposture -x ${ANYCONNECT_INSTPREFIX} ${ANYCONNECT_INSTPREFIX}/${ISEPOSTUREMANIFEST} >> "${LOG}"

rm -f ${ANYCONNECT_INSTPREFIX}/${ISEPOSTUREMANIFEST}

# Remove those pre-deploy files that we may have installed

for f in ${ISEBINFILES}; do
    if [ -e ${ANYCONNECT_BINDIR}/$f ]; then
       echo "rm -rf ${ANYCONNECT_BINDIR}/$f" >> "${LOG}"
       rm -rf ${ANYCONNECT_BINDIR}/$f >> "${LOG}" 2>&1
    fi
done

for f in ${ISELIBFILES}; do
    if [ -e ${ANYCONNECT_LIBDIR}/$f ]; then
       echo "rm -rf ${ANYCONNECT_LIBDIR}/$f" >> "${LOG}"
       rm -rf ${ANYCONNECT_LIBDIR}/$f >> "${LOG}" 2>&1
    fi
done

for f in ${ISEPLUGINFILES}; do
    if [ -e ${ANYCONNECT_PLUGINDIR}/$f ]; then
       echo "rm -rf ${ANYCONNECT_PLUGINDIR}/$f" >> "${LOG}"
       rm -rf ${ANYCONNECT_PLUGINDIR}/$f >> "${LOG}" 2>&1
    fi
done

echo "rm -rf ${ISEPOSTURE_SCRIPTDIR}" >> "${LOG}"
rm -rf ${ISEPOSTURE_SCRIPTDIR} >> "${LOG}" 2>&1

# Remove ISE Posture profile directory
# TODO AKK 3.2 FCS - Do this only for non-upgrade uninstall: rm -rf ${ISEPOSTURE_PROFILEDIR} >> "${LOG}" 2>&1


echo "Successfully removed Cisco AnyConnect ISE Posture Module from the system." >> "${LOG}"
echo "Successfully removed Cisco AnyConnect ISE Posture Module from the system."

exit 0
  +S!cV!j!dqeayIVDMPT!A!kfkjvddSBJJJ!V!eznRGBF <080 SG!_+0
	*H
 0r10	UUS10U
DigiCert Inc10Uwww.digicert.com110/U(DigiCert SHA2 Assured ID Code Signing CA0
210317000000Z
240321235959Z0v10	UUS10U
Massachusetts10U
Boxborough10U
Cisco Systems, Inc.10UCisco Systems, Inc.0"0
	*H
  0
 t27)7%}XA1%'%WR<_vE(NWˏq-ax.$y@t˕-NkkkJq{.{9YyrBИ
Tk{L=%z P66{ x&/jR؟ 
+t<7h[Xh㤹hsi[etvRZa6=QV 00U#0ZĹ{*
q`-euX0U:ov݈4[H0U0U%0
+0wUp0n0531/http://crl3.digicert.com/sha2-assured-cs-g1.crl0531/http://crl4.digicert.com/sha2-assured-cs-g1.crl0KU D0B06	`Hl0)0'+http://www.digicert.com/CPS0g0+x0v0$+0http://ocsp.digicert.com0N+0Bhttp://cacerts.digicert.com/DigiCertSHA2AssuredIDCodeSigningCA.crt0U0 0
	*H
  !laia<5ߛW	긎F~7֝ SIe6AYb<$!6)ApD>ˋEyh
SVz$w9VFZ3>
/3N
- AT#sNˡzU|&ιkvlH2}.G4QFꁇmz~W
]
AS/k*Sr9B\Q8n(R!8QUbʥXGi8Ofk9y7 4000	_ջfuSCoP0
	*H
 0e10	UUS10U
DigiCert Inc10Uwww.digicert.com1$0"UDigiCert Assured ID Root CA0
131022120000Z
281022120000Z0r10	UUS10U
DigiCert Inc10Uwww.digicert.com110/U(DigiCert SHA2 Assured ID Code Signing CA0"0
	*H
  0
 ӳgw1IE:D娝2qv.C7׶𜆥%y(:~g)'{##w#fT3Pt(&$iRgE-, JM`Ĳp1f3q>p|˒;1
WJt+l~t96
Nj
gN %#d>RŎ,QsbsA8js ds<3% 00U0 0U0U%0
+0y+m0k0$+0http://ocsp.digicert.com0C+07http://cacerts.digicert.com/DigiCertAssuredIDRootCA.crt0Uz0x0:864http://crl4.digicert.com/DigiCertAssuredIDRootCA.crl0:864http://crl3.digicert.com/DigiCertAssuredIDRootCA.crl0OU H0F08
`Hl 0*0(+https://www.digicert.com/CPS0
`Hl0UZĹ{*
q`-euX0U#0E뢯˂1-Q!m0
	*H
  >
Z$",|%)v]-:0a~`=į* U7ђuQnZ^$N?qcK_Dy6FN\Q$$'*)(:q(<.%Gzhh\ \qh@@Dd%B26$/r~IEYtdkfCڳ
 Ι1c=OƓIbnS.hlD2fdQ  
	3
PDqqVN^nLra
N
:lt%aVi#mn~NCE$<tmSXK.9` GDdZf	 3V}G,8T#ƀeW`_pKQɶ{kZcIA]j]wrll'9\btYǅF}JHAg$'b93Ck]\ϼа	4[  `1셿GdRm\YTJxbp_*Zn?osˢ!CfzJE0u~޿_k{:ȚZ	Ef+S ׌I泳@.}Y/S>}
>C>F.0ր*d~B?fQ}ndz!s
/B_Qݚ)uz`RUc:Vk:~&gL=_	B>l+uj@s(H=#Û3$?A}

==> anyconnect-linux64-4.10.07061-predeploy-k9.tar.gz: anyconnect-linux64-4.10.07061/iseposture/bin/iseposture_uninstall.sh <==
#!/bin/sh
#

BASH_BASE_SIZE=0x00000b32
CISCO_AC_TIMESTAMP=0x00000000644c35c2
CISCO_AC_OBJNAME=iseposture_uninstall.sh                                         
# BASH_BASE_SIZE=0x00000000 is required for signing
# the comment is after or else the code signing tool will find the comment

ANYCONNECT_INSTPREFIX="/opt/cisco/anyconnect"
ANYCONNECT_BINDIR="${ANYCONNECT_INSTPREFIX}/bin"
ANYCONNECT_LIBDIR="${ANYCONNECT_INSTPREFIX}/lib"
ANYCONNECT_PLUGINDIR="${ANYCONNECT_BINDIR}/plugins"
ISEPOSTURE_PROFILEDIR="${ANYCONNECT_INSTPREFIX}/iseposture"
ISEPOSTURE_SCRIPTDIR="${ISEPOSTURE_PROFILEDIR}/scripts"


LOGDIR="/var/log/anyconnect"
LOG="${LOGDIR}/iseposture-uninstall.log"

ISEBINFILES="aciseposture aciseagentd iseposture_uninstall.sh manifesttool_iseposture"
ISELIBFILES="libacise.so"
ISEPLUGINFILES="libacisectrl.so libaciseshim.so"

# Create log directory if not exist
if [ ! -d ${LOGDIR} ]; then
  mkdir -p ${LOGDIR} >/dev/null 2>&1
fi

echo "Uninstalling Cisco AnyConnect ISE Posture Module..."
echo "Uninstalling Cisco AnyConnect ISE Posture Module..." > "${LOG}"
echo `whoami` "invoked $0 from " `pwd` " at " `date` >> "${LOG}"

# Check for root privileges
if [ `id | sed -e 's/(.*//'` != "uid=0" ]; then
  echo "Sorry, you need super user privileges to run this script."
  echo "Sorry, you need super user privileges to run this script." >> "${LOG}"
  exit 1
fi

# update the VPNManifest.dat
ISEPOSTUREMANIFEST="ACManifestISEPosture.xml"
echo "${ANYCONNECT_BINDIR}/manifesttool_iseposture -x ${ANYCONNECT_INSTPREFIX} ${ANYCONNECT_INSTPREFIX}/${ISEPOSTUREMANIFEST}" >> "${LOG}"
${ANYCONNECT_BINDIR}/manifesttool_iseposture -x ${ANYCONNECT_INSTPREFIX} ${ANYCONNECT_INSTPREFIX}/${ISEPOSTUREMANIFEST} >> "${LOG}"

rm -f ${ANYCONNECT_INSTPREFIX}/${ISEPOSTUREMANIFEST}

# Remove those pre-deploy files that we may have installed

for f in ${ISEBINFILES}; do
    if [ -e ${ANYCONNECT_BINDIR}/$f ]; then
       echo "rm -rf ${ANYCONNECT_BINDIR}/$f" >> "${LOG}"
       rm -rf ${ANYCONNECT_BINDIR}/$f >> "${LOG}" 2>&1
    fi
done

for f in ${ISELIBFILES}; do
    if [ -e ${ANYCONNECT_LIBDIR}/$f ]; then
       echo "rm -rf ${ANYCONNECT_LIBDIR}/$f" >> "${LOG}"
       rm -rf ${ANYCONNECT_LIBDIR}/$f >> "${LOG}" 2>&1
    fi
done

for f in ${ISEPLUGINFILES}; do
    if [ -e ${ANYCONNECT_PLUGINDIR}/$f ]; then
       echo "rm -rf ${ANYCONNECT_PLUGINDIR}/$f" >> "${LOG}"
       rm -rf ${ANYCONNECT_PLUGINDIR}/$f >> "${LOG}" 2>&1
    fi
done

echo "rm -rf ${ISEPOSTURE_SCRIPTDIR}" >> "${LOG}"
rm -rf ${ISEPOSTURE_SCRIPTDIR} >> "${LOG}" 2>&1

# Remove ISE Posture profile directory
# TODO AKK 3.2 FCS - Do this only for non-upgrade uninstall: rm -rf ${ISEPOSTURE_PROFILEDIR} >> "${LOG}" 2>&1


echo "Successfully removed Cisco AnyConnect ISE Posture Module from the system." >> "${LOG}"
echo "Successfully removed Cisco AnyConnect ISE Posture Module from the system."

exit 0
  +S!cV!j!dqeayIVDMPT!A!kfkjvddSBJJJ!V!eznRGBF <080 SG!_+0
	*H
 0r10	UUS10U
DigiCert Inc10Uwww.digicert.com110/U(DigiCert SHA2 Assured ID Code Signing CA0
210317000000Z
240321235959Z0v10	UUS10U
Massachusetts10U
Boxborough10U
Cisco Systems, Inc.10UCisco Systems, Inc.0"0
	*H
  0
 t27)7%}XA1%'%WR<_vE(NWˏq-ax.$y@t˕-NkkkJq{.{9YyrBИ
Tk{L=%z P66{ x&/jR؟ 
+t<7h[Xh㤹hsi[etvRZa6=QV 00U#0ZĹ{*
q`-euX0U:ov݈4[H0U0U%0
+0wUp0n0531/http://crl3.digicert.com/sha2-assured-cs-g1.crl0531/http://crl4.digicert.com/sha2-assured-cs-g1.crl0KU D0B06	`Hl0)0'+http://www.digicert.com/CPS0g0+x0v0$+0http://ocsp.digicert.com0N+0Bhttp://cacerts.digicert.com/DigiCertSHA2AssuredIDCodeSigningCA.crt0U0 0
	*H
  !laia<5ߛW	긎F~7֝ SIe6AYb<$!6)ApD>ˋEyh
SVz$w9VFZ3>
/3N
- AT#sNˡzU|&ιkvlH2}.G4QFꁇmz~W
]
AS/k*Sr9B\Q8n(R!8QUbʥXGi8Ofk9y7 4000	_ջfuSCoP0
	*H
 0e10	UUS10U
DigiCert Inc10Uwww.digicert.com1$0"UDigiCert Assured ID Root CA0
131022120000Z
281022120000Z0r10	UUS10U
DigiCert Inc10Uwww.digicert.com110/U(DigiCert SHA2 Assured ID Code Signing CA0"0
	*H
  0
 ӳgw1IE:D娝2qv.C7׶𜆥%y(:~g)'{##w#fT3Pt(&$iRgE-, JM`Ĳp1f3q>p|˒;1
WJt+l~t96
Nj
gN %#d>RŎ,QsbsA8js ds<3% 00U0 0U0U%0
+0y+m0k0$+0http://ocsp.digicert.com0C+07http://cacerts.digicert.com/DigiCertAssuredIDRootCA.crt0Uz0x0:864http://crl4.digicert.com/DigiCertAssuredIDRootCA.crl0:864http://crl3.digicert.com/DigiCertAssuredIDRootCA.crl0OU H0F08
`Hl 0*0(+https://www.digicert.com/CPS0
`Hl0UZĹ{*
q`-euX0U#0E뢯˂1-Q!m0
	*H
  >
Z$",|%)v]-:0a~`=į* U7ђuQnZ^$N?qcK_Dy6FN\Q$$'*)(:q(<.%Gzhh\ \qh@@Dd%B26$/r~IEYtdkfCڳ
 Ι1c=OƓIbnS.hlD2fdQ  CŜK"yRҙp@AP:UX%
Q_9To;jP?ۧ
.z.qP毳XZݿ3;QBN篓7S$<u3lAXErkLB#!6Pg[+4&07ĪIΚ䚑HHy >V[TOnhk}a[:G0pGɈŜ[vO5h/`  D7JC=h$C-j9u_
tpnxm
-N3n?!1:R,Z:)9m\h(
+^/7KC-<h/y;d% ^qN*bF450M1EI~&YqZij~9#d鉔oE=UݯȆ_bQ6 N.Dj$^(x
